@@ -1,4 +1,4 @@
-# ZestyParser 0.4.0 -- Parses in Python zestily
+# ZestyParser 0.4.1 -- Parses in Python zestily
 # Copyright (C) 2006 Adam Atlas
 # 
 # This program is free software; you can redistribute it and/or
@@ -204,7 +204,8 @@ class ZestyParser:
 	
 	def iter(self, tokens): return ParserIterator(tokens, self)
 	
-	def coord(self, loc=self.cursor):
+	def coord(self, loc=None):
+		if not loc: loc = self.cursor
 		row = self.data.count('\n', 0, loc)
 		col = loc - self.data.rfind('\n', 0, loc)
 		return (row + 1, col)
